
**SuperalloyDataExtractor**
----------------------
The functions of superalloydataextractor toolkit include batch downloading documents in XML and TXT format from the Elsevier database, locating target sentences from the full text and automatically extracting triple information in the form of <material name, property specifier, value>.

This package is released under MIT License, please see the LICENSE file for details.

**Features**
----------------------
- Rule-based named entity recognition for superalloy.
- An automated data extraction pipeline for superalloy.
- Algorithm based on distance and number of entities, processing multiple relationship extraction without labeling samples.

**USAGE**
----------------------
Clone this github repository and run
```
python3 setup.py install
```

Or simply use the code in your own project.

**LICENSE**
----------------------
All source code is licensed under the MIT license.

**Install**
----------------------
```
pip install superalloydataextractor
```
or if you are an Anaconda user, run:

```
conda install -c superalloydataextractor superalloydataextractor
```
